@@ -913,7 +913,7 @@ sub start_url
 {
     ( $element, $event ) = @_;
     my $id = _normalize( _a( 'ID' ) );
-    my $name = _normalize( _a( 'NAME' ) );
+    my $name =  _a( 'NAME' );
     $name = "" if ( $name eq '\|\|' ) || ( $name eq '\|urlname\|' )
 	|| ( $name eq $id );
     &{$Format."::"._output_url}( $id, $name ) if length( $id );
