@@ -952,7 +952,9 @@ sub _output_url
 {
     my $url = URI->new( $_[0] );
     $_[1] = $_[0] if $_[1] eq "";
-    output( "<code><a href=\"$url\">$_[1]</a></code>" );
+    output( "<code><a href=\"$url\">" );
+    _cdata( $_[1] );
+    output( "</a></code>" );
 }
 
 ## ----------------------------------------------------------------------
