@@ -661,7 +661,9 @@ sub _output_url
 {
 #    my $url = URI->new( $_[0] );
 #    $_[1] = $_[0] if $_[1] eq "";
-    output( "<url id=\"$_[0]\" name=\"$_[1]\">" );
+    output( "<url id=\"" );
+    _cdata( $_[1] );
+    output( "\" name=\"$_[1]\">" );
 }
 
 ## ----------------------------------------------------------------------
