@@ -706,7 +706,9 @@ sub _output_url
 {
 #    my $url = URI->new( $_[0] );
 #    $_[1] = $_[0] if $_[1] eq "";
-    output( "<ulink url=\"$_[0]\">$_[1]</ulink>" );
+    output( "<ulink url=\"" );
+    _cdata( $_[1] );
+    output( "\">$_[1]</ulink>" );
 }
 
 ## ----------------------------------------------------------------------
